
namespace eval ::Imago {
  variable thisScriptFilename [file normalize [info script]]
  variable imagoScriptDir [file dirname $thisScriptFilename]
}

source [file join $::Imago::imagoScriptDir "imago-common.tcl"]

set imago_config [::Imago::load_config]

set database_file_path [::Imago::get_config_value imago_config "mesh_database_file_path"]

if { ![file exists $database_file_path] } {

  if { [string length [string trim $database_file_path]] == 0 } {
    ::Imago::display_warning "Invalid Database File" "Unable to create mesh, because the mesh database has not been configured. Please update the configuration and try again."
    return
  } else {
    ::Imago::display_warning "Invalid Database File" "The mesh database '${database_file_path}' can not be found. Please check configuration."
    return
  }

} else {

  if { [::Imago::confirm_mesh_type mesh_type] } {

    set macro_name ""
    if { $mesh_type == $::Imago::CORE_TRAY_MESH } {
      set macro_name "CreateMeshCoreBox"
    } elseif { $mesh_type == $::Imago::LINEAR_MESH } {
      set macro_name "CreateMeshDownhole"
    } else {
      error "Unknown mesh type: $mesh_type"
    }

    puts "Creating [::Imago::format_mesh_type $mesh_type] ..."
    ::Imago::invoke_microsoft_access_macro $database_file_path $macro_name
  }

}


